@@ -3,6 +3,7 @@ from datetime import datetime
 
 import click
 
+from nowcasting_forecast import N_GSP
 from nowcasting_forecast.batch import make_batches
 from nowcasting_forecast.database.connection import DatabaseConnection
 from nowcasting_forecast.database.fake import make_fake_forecasts, make_fake_national_forecast
@@ -10,8 +11,6 @@ from nowcasting_forecast.database.save import save
 from nowcasting_forecast.models.nwp_solar_simple import nwp_irradiance_simple_run_all_batches
 from nowcasting_forecast.utils import floor_30_minutes_dt
 
-N_GSP = 338
-
 
 @click.command()
 @click.option(
